import * as errors from './errors';
import { Container } from './Container';
import { DeprecationMessageFunc } from './middlewares/deprecated';
export * from './Definition';
export * from './Container';
export * from './Reference';
export * from './types';
export * from './ContainerArg';
export * from './referenceFunc';
export * from './configFunc';
export * from './Lookup';
export * from './middlewares/activation';
export * from './middlewares/config';
export * from './createAnnotationFactory';
export * from './middlewares/deprecated';
export { Service, getDefinitionForClass } from './decorators/Service';
export { Annotation } from './decorators/Annotation';
export { Inject } from './decorators/Inject';
export { Config } from './decorators/Config';
export { Deprecated } from './decorators/Deprecated';
export { OnActivation } from './decorators/OnActivation';
export { AutowiredService } from './decorators/AutowiredService';
export { preloadServiceModules } from './preloadServiceModules';
export { createNamespace, namespaceEntry } from './createNamespace';
export { errors };
export declare function create(parent?: Container): Container;
export interface StandardContainerOptions {
    /**
     * Configuration object for @Config decorators and annotations
     */
    config?: object;
    /**
     * A function that is responsible for displaying deprecation note. By default console.warn used
     */
    deprecationMessageFunc?: DeprecationMessageFunc;
    /**
     * Parent container
     */
    parent?: Container;
    /**
     * Whether to inform @Service decorator to use newly created container
     */
    configureServiceDecorator?: boolean;
}
/**
 * Creates preconfigured container:
 * * has all middlewares registered
 * * @Service decorator uses new container
 * * configMiddleware that uses given config object
 */
export declare function createStandard(options?: StandardContainerOptions): Container;
export declare const createContainer: typeof create;
